@@ -20,8 +20,10 @@
 */
 
 show_box_top();
-printf(_('Updating the %s catalog', " <b>[ $catalog->name ]</b> "));
-echo "<br />\n" . $number . " " . _('songs found checking tag information.') . "<br />\n\n";
+printf(_('Updating the %s catalog'), "<strong>[ $catalog->name ]</strong>");
+echo "<br />\n";
+printf(ngettext('%d item found checking tag information', '%d items found checking tag information', $number), $number);
+echo "<br />\n\n";
 echo _('Verifed') . ":<span id=\"verify_count_$catalog_id\">$catalog_verify_found</span><br />"; 
 echo _('Reading') . ":<span id=\"verify_dir_$catalog_id\">$catalog_verify_directory</span><br />";
 show_box_bottom(); 
